==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/PolicySpecFluent.java <==
package me.snowdrop.istio.api.authentication.v1alpha1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import javax.validation.Valid;
import java.util.Collection;
import java.lang.Object;

public interface PolicySpecFluent<A extends PolicySpecFluent<A>> extends Fluent<A>{


    public Boolean isOriginIsOptional();
    public A withOriginIsOptional(Boolean originIsOptional);
    public Boolean hasOriginIsOptional();
    public A withNewOriginIsOptional(String arg1);
    public A withNewOriginIsOptional(boolean arg1);
    public A addToOrigins(int index,OriginAuthenticationMethod item);
    public A setToOrigins(int index,OriginAuthenticationMethod item);
    public A addToOrigins(OriginAuthenticationMethod... items);
    public A addAllToOrigins(Collection<OriginAuthenticationMethod> items);
    public A removeFromOrigins(OriginAuthenticationMethod... items);
    public A removeAllFromOrigins(Collection<OriginAuthenticationMethod> items);
    
/**
 * This method has been deprecated, please use method buildOrigins instead.
 * @return The buildable object.
 */
@Deprecated public List<OriginAuthenticationMethod> getOrigins();
    public List<OriginAuthenticationMethod> buildOrigins();
    public OriginAuthenticationMethod buildOrigin(int index);
    public OriginAuthenticationMethod buildFirstOrigin();
    public OriginAuthenticationMethod buildLastOrigin();
    public OriginAuthenticationMethod buildMatchingOrigin(io.fabric8.kubernetes.api.builder.Predicate<OriginAuthenticationMethodBuilder> predicate);
    public A withOrigins(List<OriginAuthenticationMethod> origins);
    public A withOrigins(OriginAuthenticationMethod... origins);
    public Boolean hasOrigins();
    public PolicySpecFluent.OriginsNested<A> addNewOrigin();
    public PolicySpecFluent.OriginsNested<A> addNewOriginLike(OriginAuthenticationMethod item);
    public PolicySpecFluent.OriginsNested<A> setNewOriginLike(int index,OriginAuthenticationMethod item);
    public PolicySpecFluent.OriginsNested<A> editOrigin(int index);
    public PolicySpecFluent.OriginsNested<A> editFirstOrigin();
    public PolicySpecFluent.OriginsNested<A> editLastOrigin();
    public PolicySpecFluent.OriginsNested<A> editMatchingOrigin(io.fabric8.kubernetes.api.builder.Predicate<OriginAuthenticationMethodBuilder> predicate);
    public Boolean isPeerIsOptional();
    public A withPeerIsOptional(Boolean peerIsOptional);
    public Boolean hasPeerIsOptional();
    public A withNewPeerIsOptional(String arg1);
    public A withNewPeerIsOptional(boolean arg1);
    public A addToPeers(int index,PeerAuthenticationMethod item);
    public A setToPeers(int index,PeerAuthenticationMethod item);
    public A addToPeers(PeerAuthenticationMethod... items);
    public A addAllToPeers(Collection<PeerAuthenticationMethod> items);
    public A removeFromPeers(PeerAuthenticationMethod... items);
    public A removeAllFromPeers(Collection<PeerAuthenticationMethod> items);
    
/**
 * This method has been deprecated, please use method buildPeers instead.
 * @return The buildable object.
 */
@Deprecated public List<PeerAuthenticationMethod> getPeers();
    public List<PeerAuthenticationMethod> buildPeers();
    public PeerAuthenticationMethod buildPeer(int index);
    public PeerAuthenticationMethod buildFirstPeer();
    public PeerAuthenticationMethod buildLastPeer();
    public PeerAuthenticationMethod buildMatchingPeer(io.fabric8.kubernetes.api.builder.Predicate<PeerAuthenticationMethodBuilder> predicate);
    public A withPeers(List<PeerAuthenticationMethod> peers);
    public A withPeers(PeerAuthenticationMethod... peers);
    public Boolean hasPeers();
    public PolicySpecFluent.PeersNested<A> addNewPeer();
    public PolicySpecFluent.PeersNested<A> addNewPeerLike(PeerAuthenticationMethod item);
    public PolicySpecFluent.PeersNested<A> setNewPeerLike(int index,PeerAuthenticationMethod item);
    public PolicySpecFluent.PeersNested<A> editPeer(int index);
    public PolicySpecFluent.PeersNested<A> editFirstPeer();
    public PolicySpecFluent.PeersNested<A> editLastPeer();
    public PolicySpecFluent.PeersNested<A> editMatchingPeer(io.fabric8.kubernetes.api.builder.Predicate<PeerAuthenticationMethodBuilder> predicate);
    public PrincipalBinding getPrincipalBinding();
    public A withPrincipalBinding(PrincipalBinding principalBinding);
    public Boolean hasPrincipalBinding();
    public A addToTargets(int index,TargetSelector item);
    public A setToTargets(int index,TargetSelector item);
    public A addToTargets(TargetSelector... items);
    public A addAllToTargets(Collection<TargetSelector> items);
    public A removeFromTargets(TargetSelector... items);
    public A removeAllFromTargets(Collection<TargetSelector> items);
    
/**
 * This method has been deprecated, please use method buildTargets instead.
 * @return The buildable object.
 */
@Deprecated public List<TargetSelector> getTargets();
    public List<TargetSelector> buildTargets();
    public TargetSelector buildTarget(int index);
    public TargetSelector buildFirstTarget();
    public TargetSelector buildLastTarget();
    public TargetSelector buildMatchingTarget(io.fabric8.kubernetes.api.builder.Predicate<TargetSelectorBuilder> predicate);
    public A withTargets(List<TargetSelector> targets);
    public A withTargets(TargetSelector... targets);
    public Boolean hasTargets();
    public PolicySpecFluent.TargetsNested<A> addNewTarget();
    public PolicySpecFluent.TargetsNested<A> addNewTargetLike(TargetSelector item);
    public PolicySpecFluent.TargetsNested<A> setNewTargetLike(int index,TargetSelector item);
    public PolicySpecFluent.TargetsNested<A> editTarget(int index);
    public PolicySpecFluent.TargetsNested<A> editFirstTarget();
    public PolicySpecFluent.TargetsNested<A> editLastTarget();
    public PolicySpecFluent.TargetsNested<A> editMatchingTarget(io.fabric8.kubernetes.api.builder.Predicate<TargetSelectorBuilder> predicate);

    public interface OriginsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,OriginAuthenticationMethodFluent<PolicySpecFluent.OriginsNested<N>>{

        
    public N and();    public N endOrigin();
}
    public interface PeersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PeerAuthenticationMethodFluent<PolicySpecFluent.PeersNested<N>>{

        
    public N and();    public N endPeer();
}
    public interface TargetsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TargetSelectorFluent<PolicySpecFluent.TargetsNested<N>>{

        
    public N and();    public N endTarget();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/PolicySpecFluent.java <==
package me.snowdrop.istio.api.authentication.v1alpha1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;

public interface PolicySpecFluent<A extends PolicySpecFluent<A>> extends Fluent<A>{


    public Boolean isOriginIsOptional();
    public A withOriginIsOptional(Boolean originIsOptional);
    public Boolean hasOriginIsOptional();
    public A withNewOriginIsOptional(String arg1);
    public A withNewOriginIsOptional(boolean arg1);
    public A addToOrigins(int index,OriginAuthenticationMethod item);
    public A setToOrigins(int index,OriginAuthenticationMethod item);
    public A addToOrigins(OriginAuthenticationMethod... items);
    public A addAllToOrigins(Collection<OriginAuthenticationMethod> items);
    public A removeFromOrigins(OriginAuthenticationMethod... items);
    public A removeAllFromOrigins(Collection<OriginAuthenticationMethod> items);
    public A removeMatchingFromOrigins(io.fabric8.kubernetes.api.builder.Predicate<OriginAuthenticationMethodBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildOrigins instead.
 * @return The buildable object.
 */
@Deprecated public List<OriginAuthenticationMethod> getOrigins();
    public List<OriginAuthenticationMethod> buildOrigins();
    public OriginAuthenticationMethod buildOrigin(int index);
    public OriginAuthenticationMethod buildFirstOrigin();
    public OriginAuthenticationMethod buildLastOrigin();
    public OriginAuthenticationMethod buildMatchingOrigin(io.fabric8.kubernetes.api.builder.Predicate<OriginAuthenticationMethodBuilder> predicate);
    public Boolean hasMatchingOrigin(io.fabric8.kubernetes.api.builder.Predicate<OriginAuthenticationMethodBuilder> predicate);
    public A withOrigins(List<OriginAuthenticationMethod> origins);
    public A withOrigins(OriginAuthenticationMethod... origins);
    public Boolean hasOrigins();
    public PolicySpecFluent.OriginsNested<A> addNewOrigin();
    public PolicySpecFluent.OriginsNested<A> addNewOriginLike(OriginAuthenticationMethod item);
    public PolicySpecFluent.OriginsNested<A> setNewOriginLike(int index,OriginAuthenticationMethod item);
    public PolicySpecFluent.OriginsNested<A> editOrigin(int index);
    public PolicySpecFluent.OriginsNested<A> editFirstOrigin();
    public PolicySpecFluent.OriginsNested<A> editLastOrigin();
    public PolicySpecFluent.OriginsNested<A> editMatchingOrigin(io.fabric8.kubernetes.api.builder.Predicate<OriginAuthenticationMethodBuilder> predicate);
    public Boolean isPeerIsOptional();
    public A withPeerIsOptional(Boolean peerIsOptional);
    public Boolean hasPeerIsOptional();
    public A withNewPeerIsOptional(String arg1);
    public A withNewPeerIsOptional(boolean arg1);
    public A addToPeers(int index,PeerAuthenticationMethod item);
    public A setToPeers(int index,PeerAuthenticationMethod item);
    public A addToPeers(PeerAuthenticationMethod... items);
    public A addAllToPeers(Collection<PeerAuthenticationMethod> items);
    public A removeFromPeers(PeerAuthenticationMethod... items);
    public A removeAllFromPeers(Collection<PeerAuthenticationMethod> items);
    public A removeMatchingFromPeers(io.fabric8.kubernetes.api.builder.Predicate<PeerAuthenticationMethodBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildPeers instead.
 * @return The buildable object.
 */
@Deprecated public List<PeerAuthenticationMethod> getPeers();
    public List<PeerAuthenticationMethod> buildPeers();
    public PeerAuthenticationMethod buildPeer(int index);
    public PeerAuthenticationMethod buildFirstPeer();
    public PeerAuthenticationMethod buildLastPeer();
    public PeerAuthenticationMethod buildMatchingPeer(io.fabric8.kubernetes.api.builder.Predicate<PeerAuthenticationMethodBuilder> predicate);
    public Boolean hasMatchingPeer(io.fabric8.kubernetes.api.builder.Predicate<PeerAuthenticationMethodBuilder> predicate);
    public A withPeers(List<PeerAuthenticationMethod> peers);
    public A withPeers(PeerAuthenticationMethod... peers);
    public Boolean hasPeers();
    public PolicySpecFluent.PeersNested<A> addNewPeer();
    public PolicySpecFluent.PeersNested<A> addNewPeerLike(PeerAuthenticationMethod item);
    public PolicySpecFluent.PeersNested<A> setNewPeerLike(int index,PeerAuthenticationMethod item);
    public PolicySpecFluent.PeersNested<A> editPeer(int index);
    public PolicySpecFluent.PeersNested<A> editFirstPeer();
    public PolicySpecFluent.PeersNested<A> editLastPeer();
    public PolicySpecFluent.PeersNested<A> editMatchingPeer(io.fabric8.kubernetes.api.builder.Predicate<PeerAuthenticationMethodBuilder> predicate);
    public PrincipalBinding getPrincipalBinding();
    public A withPrincipalBinding(PrincipalBinding principalBinding);
    public Boolean hasPrincipalBinding();
    public A addToTargets(int index,TargetSelector item);
    public A setToTargets(int index,TargetSelector item);
    public A addToTargets(TargetSelector... items);
    public A addAllToTargets(Collection<TargetSelector> items);
    public A removeFromTargets(TargetSelector... items);
    public A removeAllFromTargets(Collection<TargetSelector> items);
    public A removeMatchingFromTargets(io.fabric8.kubernetes.api.builder.Predicate<TargetSelectorBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTargets instead.
 * @return The buildable object.
 */
@Deprecated public List<TargetSelector> getTargets();
    public List<TargetSelector> buildTargets();
    public TargetSelector buildTarget(int index);
    public TargetSelector buildFirstTarget();
    public TargetSelector buildLastTarget();
    public TargetSelector buildMatchingTarget(io.fabric8.kubernetes.api.builder.Predicate<TargetSelectorBuilder> predicate);
    public Boolean hasMatchingTarget(io.fabric8.kubernetes.api.builder.Predicate<TargetSelectorBuilder> predicate);
    public A withTargets(List<TargetSelector> targets);
    public A withTargets(TargetSelector... targets);
    public Boolean hasTargets();
    public PolicySpecFluent.TargetsNested<A> addNewTarget();
    public PolicySpecFluent.TargetsNested<A> addNewTargetLike(TargetSelector item);
    public PolicySpecFluent.TargetsNested<A> setNewTargetLike(int index,TargetSelector item);
    public PolicySpecFluent.TargetsNested<A> editTarget(int index);
    public PolicySpecFluent.TargetsNested<A> editFirstTarget();
    public PolicySpecFluent.TargetsNested<A> editLastTarget();
    public PolicySpecFluent.TargetsNested<A> editMatchingTarget(io.fabric8.kubernetes.api.builder.Predicate<TargetSelectorBuilder> predicate);

    public interface OriginsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,OriginAuthenticationMethodFluent<PolicySpecFluent.OriginsNested<N>>{

        
    public N and();    public N endOrigin();
}
    public interface PeersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PeerAuthenticationMethodFluent<PolicySpecFluent.PeersNested<N>>{

        
    public N and();    public N endPeer();
}
    public interface TargetsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TargetSelectorFluent<PolicySpecFluent.TargetsNested<N>>{

        
    public N and();    public N endTarget();
}


}
